Index: src/compiler/bytecode-graph-builder.h |
diff --git a/src/compiler/bytecode-graph-builder.h b/src/compiler/bytecode-graph-builder.h |
index f11127ef5a56cc30b98545cc1f8d11966707329c..4bae34e3d96f4ff604c7bd805d9efcd1ba47590d 100644 |
--- a/src/compiler/bytecode-graph-builder.h |
+++ b/src/compiler/bytecode-graph-builder.h |
@@ -169,9 +169,10 @@ class BytecodeGraphBuilder { |
// underlying bytecode. The exception handlers within the bytecode are |
// well scoped, hence will form a stack during iteration. |
struct ExceptionHandler { |
- int start_offset_; // Start offset of the handled area in the bytecode. |
- int end_offset_; // End offset of the handled area in the bytecode. |
- int handler_offset_; // Handler entry offset within the bytecode. |
+ int start_offset_; // Start offset of the handled area in the bytecode. |
+ int end_offset_; // End offset of the handled area in the bytecode. |
+ int handler_offset_; // Handler entry offset within the bytecode. |
+ int context_register_; // Index of register holding handler context. |
}; |
// Field accessors |